import Vue from 'vue';
import Router from 'vue-router';
import { Router as RouterDirect, Config } from '@zeedhi/core';
import { ZdPage } from '@zeedhi/vue';
import Store from './store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('./views/Home.vue'),
    },
    {
      path: '/zeedhi',
      name: 'zeedhi',
      component: ZdPage,
      props: () => ({
        path: 'zeedhi',
        local: true,
      }),
    },
    {
      path: '/Lista_Tarefas',
      name: 'ListaTarefas',
      component: ZdPage,
      props: () => ({
        path: 'listaTarefas',
        local: true,
      }),
    },
    {
      path: '/Tarefas',
      name: 'Minhas Tarefas',
      component: ZdPage,
      props: () => ({
        path: 'minhasTarefas',
        local: true,
      }),
    },
    {
      path: '/login',
      name: 'login',
      component: ZdPage,
      props: () => ({
        path: 'login',
        local: true,
      }),
    },
    {
      path: '/Detalhes_Tarefa/:nr',
      name: 'DetalhamentoTarefa',
      component: ZdPage,
      props: () => ({
        path: 'detalhamentoTarefa',
        local: true,
      }),
    },
    {
      path: '/conformidades',
      name: 'Não_Conformidades',
      component: ZdPage,
      props: () => ({
        path: 'conformidades',
        local: true,
      }),
    },
    {
      path: '/Reportar_Tarefa/:nr',
      name: 'ReportarTarefa',
      component: ZdPage,
      props: () => ({
        path: 'reportarTarefa',
        local: true,
      }),
    },
    {
      path: '/Dashboard',
      name: 'Dashboard',
      component: ZdPage,
      props: () => ({
        path: 'dashboard',
        local: true,
      }),
    },
    {
      path: '/dashboardSupervisor',
      name: 'Dashboard_Supervisor',
      component: ZdPage,
      props: () => ({
        path: 'dashboardSupervisor',
        local: true,
      }),
    },
    {
      path: '/Vistorias',
      name: 'Vistorias',
      component: ZdPage,
      props: () => ({
        path: 'listagemVistorias',
        local: true,
      }),
    },
    {
      path: '/Detalhes_Vistoria/:nr/:local',
      name: 'Vistoria',
      component: ZdPage,
      props: () => ({
        path: 'detalhesVistoria',
        local: true,
      }),
    },
    {
      path: '/Calendario',
      name: 'Calendario',
      component: ZdPage,
      props: () => ({
        path: 'calendario',
        local: true,
      }),
    },
    {
      path: '/registrarApontamento',
      name: 'Registrar_Apontamento',
      component: ZdPage,
      props: () => ({
        path: 'registrarApontamento',
        local: true,
      }),
    },
    {
      path: '/solicitacoesTarefas',
      name: 'Solicitacoes_Tarefas',
      component: ZdPage,
      props: () => ({
        path: 'solicitacoesTarefas',
        local: true,
      }),
    },
    {
      path: '/registrarFalta',
      name: 'Registrar_Falta',
      component: ZdPage,
      props: () => ({
        path: 'registrarFalta',
        local: true,
      }),
    },
    {
      path: '/solicitacaoTarefa',
      name: 'Solicitacao_Tarefaa',
      component: ZdPage,
      props: () => ({
        path: 'solicitacaoTarefa',
        local: true,
      }),
    },
    {
      path: '/criarSolicitacao',
      name: 'criar_solicitacao',
      component: ZdPage,
      props: () => ({
        path: 'criarSolicitacaoTarefa',
        local: true,
      }),
    },
    {
      path: '/avaliarSolicitacao',
      name: 'avaliar_solicitacao',
      component: ZdPage,
      props: () => ({
        path: 'avaliarSolicitacao',
        local: true,
      }),
    },
    {
      path: '/modules/:module/:page',
      name: 'microservice',
      component: () => import('./views/Microservice.vue'),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
  ],
});

router.beforeEach((to, from, next) => {
  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    const dashboards: any = { O: '/dashboard', S: '/dashboardSupervisor', G: '/dashboardGerencial' };
    const rotaDash = dashboards[<string>localStorage.getItem('IDTIPODASHBOARD')];
    if (to.path.includes('dashboard') && to.path !== rotaDash) {
      RouterDirect.replace(rotaDash);
    }
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export const getRouteParams = () => {
  const { currentRoute } = router;
  const { params } = currentRoute;
  return params;
};

export const getRoutePath = () => {
  const { currentRoute } = router;
  const { path } = currentRoute;
  return path;
};

export default router;
